==> haskell-retry-0.9.3.1-40-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-4DkhyXQVdEO6NCSBFSc7an
key:                  retry-0.9.3.1-4DkhyXQVdEO6NCSBFSc7an
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  7e2efd226975677d62e2837472ce84cf
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-4DkhyXQVdEO6NCSBFSc7an
depends:
    base-4.16.4.0 exceptions-0.10.4 ghc-prim-0.8.0 mtl-2.2.2
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.9.3.1-73.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-7uewXMWyGgHDHK73hMpuXF
key:                  retry-0.9.3.1-7uewXMWyGgHDHK73hMpuXF
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  513b21c96de5964ae453240822a10a4b
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/retry-0.9.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-7uewXMWyGgHDHK73hMpuXF
depends:
    base-4.17.2.1 exceptions-0.10.5 ghc-prim-0.9.1 mtl-2.2.2
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
